# pDESy: Discrete Time-Event Simulator in Python

[![PyPI version](https://badge.fury.io/py/pDESy.svg)](https://badge.fury.io/py/pDESy)
[![test](https://github.com/pDESy/pDESy/actions/workflows/test.yaml/badge.svg)](https://github.com/pDESy/pDESy/actions/workflows/test.yaml)
[![codecov](https://codecov.io/gh/pDESy/pDESy/branch/master/graph/badge.svg)](https://codecov.io/gh/pDESy/pDESy)

## What is it?

**pDESy** is a Python package of Discrete Time-Event Simulator (DES). It aims to be the fundamental high-level building block for doing practical, real world engineering project management by using DES and other DES modeling tools. **pDESy** has only the function of discrete-event simulation, does not include the function of visual modeling.

## Where to get it

The source code is currently hosted on GitHub at: [https://github.com/pDESy/pDESy](https://github.com/pDESy/pDESy)

Binary installers for the latest released version will be available at the Python package index. Now, please install pDESy as following.

```sh
pip install pDESy
# pip install git+ssh://git@github.com/pDESy/pDESy.git # INSTALL FROM GITHUB
```

## License

[MIT](https://github.com/pDESy/pDESy/blob/master/LICENSE)

## Documentation

API Documentation is [https://pDESy.github.io/pDESy/index.html](https://pDESy.github.io/pDESy/index.html).

## Background

**pDESy** is developed by a part of next generation DES tool of **[pDES](https://github.com/pDESy/pDES)**.

## Citation

Mitsuyuki, T., & Okubo, Y. (2024). pDESy: A Python Package for Discrete Time-Event Simulation to Engineering Project. Software Impacts, 19(100621). <https://doi.org/10.1016/j.simpa.2024.100621>

    @article{Mitsuyuki_pDESy_A_Python_2024,
        author = {Mitsuyuki, Taiga and Okubo, Yui},
        doi = {10.1016/j.simpa.2024.100621},
        journal = {Software Impacts},
        month = mar,
        number = {100621},
        title = {pDESy: A Python Package for Discrete Time-Event Simulation to Engineering Project},
        volume = {19},
        year = {2024}
    }

## Contribution

1. Fork it ( <http://github.com/pDESy/pDESy/fork> )
2. Create your feature branch (git checkout -b my-new-feature)
3. Commit your changes (git commit -am 'Add some feature')
4. Push to the branch (git push origin my-new-feature)
5. Create new Pull Request

If you want to join this project as a researcher, please contact [me](https://github.com/taiga4112).
